String[][] working_data;
int drawCount = 0;
int rowIndex = 0;

BeachData montroseData;
//BeachData ohioData;

Wave [] waves;

void setup() {
  background(255);
  size(displayWidth, displayHeight);
  orientation(LANDSCAPE);

  int rowCount = 0;
  String[] original_data = loadStrings("data.csv");
  working_data = new String[original_data.length][];
  
  for (int i = 0; i < original_data.length; i++) {
    
    // this is just a check to see if the line we're looking at is empty
    if (trim(original_data[i]).length() == 0) {
      continue; // skip empty rows
    }
    
    // split the row on the tabs
    String[] cells_for_this_row = split(original_data[i], ",");
    
    // copy to the table array
    working_data[rowCount] = new String[cells_for_this_row.length];
    working_data[rowCount] = cells_for_this_row;
    
    rowCount++;
  }
  // resize the 'data' array as necessary
  working_data = (String[][]) subset(working_data, 0, rowCount);
  
  // start at the last row of the file
  rowIndex = rowCount-2;
  
  waves = new Wave[5];
  for (int i = 0; i < waves.length; i++) {
   waves[i] = new Wave((height/6)*(i+1)); 
  }
 
  montroseData = new BeachData();
  //ohioData = new BeachData();
  
  findMaxWaveHeight();
  findMaxWavePeriod();
  findMinMaxWaterTemperature();
}



void findMaxWaveHeight()
{
  for (int i = 0; i < working_data.length; i++) {
    float waveHeight = Float.parseFloat(working_data[i][WaveHeightColumn]);
    
    montroseData.maxWaveHeight = max(montroseData.maxWaveHeight, waveHeight);
    //ohioData.maxWaveHeight     = max(ohioData.maxWaveHeight, waveHeight);
  }
}



void findMaxWavePeriod()
{
  for (int i = 0; i < working_data.length; i++) {
    float wavePeriod = Float.parseFloat(working_data[i][WavePeriodColumn]);
    
    montroseData.maxWavePeriod = max(montroseData.maxWavePeriod, wavePeriod);
    //ohioData.maxWavePeriod     = max(ohioData.maxWavePeriod, wavePeriod);
  }
}



void findMinMaxWaterTemperature()
{  
  for (int i = 0; i < working_data.length; i++) {
    float waterTemp = Float.parseFloat(working_data[i][WaterTemperatureColumn]);
    
    montroseData.minWaterTemperature = min(montroseData.minWaterTemperature, waterTemp);
    montroseData.maxWaterTemperature = max(montroseData.maxWaterTemperature, waterTemp);
    //ohioData.maxWaterTemperature     = max(ohioData.maxWaterTemperature, waterTemp);
  }
}


void draw() {

  noStroke();
  
  String beachName = working_data[rowIndex][BeachNameColumn];
  
  // use this row to update the current data
  if (beachName.equals("Montrose Beach")) {
    montroseData.update(working_data[rowIndex]);
  }// else {
    //ohioData.update(working_data[rowIndex]);
  //}
  
  // step to the next row every 30 draw calls (.5 seconds)
  if (drawCount++ % 30 == 0) {
    rowIndex--;
  }
  
  float temperatureRange = montroseData.maxWaterTemperature - montroseData.minWaterTemperature;
  
  // color range of 256 values is too large for our temperature range; scale accordingly 
  float rgbStep = 255.0 / temperatureRange;
  float degreesFromMin = montroseData.waterTemperature - montroseData.minWaterTemperature;  
  int rgValue = (int)(degreesFromMin * rgbStep);
  
  // paint the background a warmer (more teal) color if the temperature is warmer
  background(rgValue/5, rgValue*1.5, 206);
  
  for (int i = 0; i < waves.length; i++) {
    
    // determine this wave's amplitude as a percentage of max amplitude and draw it as that same percentage of window height
    waves[i].amplitude = (montroseData.waveHeight / montroseData.maxWaveHeight) * height;
    // determine this wave's period as a percentage of max period and draw it as that same percentage of window width
    waves[i].updatePeriod((montroseData.wavePeriod / montroseData.maxWavePeriod) * width);
    
    waves[i].draw();
  }
}

void mouseWheel(MouseEvent event)
{
  // did they scroll up or down?
  float sizeChange = event.getCount();
  
  for (int i = 0; i < waves.length; i++) {
    waves[i].circleSize -= sizeChange; 
  }
}
